pub trait Config: Config {
type ForeignAssetId: Member + Parameter + Clone + MaybeSerializeDeserialize + MaxEncodedLen;
type AssetsInstance: 'static;
}Expand description
Configuration trait of this pallet.
The main purpose of this trait is to act as an interface between this pallet and the runtime in which it is embedded in. A type, function, or constant in this trait is essentially left to be configured by the runtime that includes this pallet.
Consequently, a runtime that wants to include this pallet must implement this trait.
Required Associated Types
Sourcetype ForeignAssetId: Member + Parameter + Clone + MaybeSerializeDeserialize + MaxEncodedLen
type ForeignAssetId: Member + Parameter + Clone + MaybeSerializeDeserialize + MaxEncodedLen
The foreign asset ID type. This must match the AssetId type used by the
pallet_assets instance for foreign assets.
Sourcetype AssetsInstance: 'static
type AssetsInstance: 'static
The pallet_assets instance that holds foreign assets.
Used by benchmarks to interact with the correct assets instance.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.